<?php
declare (strict_types = 1);

namespace app\admin\controller;

use think\facade\Session;
use think\facade\Request;
use app\common\util\Upload as Up;
use app\common\model\AdminPhoto as P;
use app\common\service\AdminAdmin as S;
use think\facade\Db;
use app\common\model\YpayOrder;
use app\common\model\YpayRecharge;
use app\common\model\YpayAccount;
use think\facade\View;
use app\common\model\YpayUser;

class Index extends Base
{
    protected $middleware = ['AdminCheck','AdminPermission'];
    
    // 首页
    public function index(){
        return $this->fetch('',[
            'nickname'  => get_field('admin_admin',Session::get('admin.id'),'nickname')
        ]);
    }

    // 清除缓存
    public function cache(){
        Session::clear();
         return $this->getJson(rm());
        }

    // 菜单
    public function menu(){
        return json(get_tree(Session::get('admin.menu')));
    }

    // 欢迎页
    public function home(){
        $total_water_order = YpayOrder::where('status',1)->count();//平台总流水订单
        $total_recharge_order = YpayRecharge::where('status',1)->count();//平台总充值订单
        $data = 
        [
            //顶部4格
            "total_money" => YpayOrder::where('status',1)->sum('truemoney'),//平台总流水
            "total_order" => $total_water_order + $total_recharge_order,//平台总订单
            "total_user"  => YpayUser::count(),//平台总用户
            "total_recharge" => YpayRecharge::where('status',1)->sum('money'),//平台总充值
            //统计图 - 总流水
            "wechat_month_money" => YpayOrder::where('status',1)->whereTime('create_time', 'month')->where('type','wxpay')->sum('truemoney'),//微信本月总金额
            "wechat_week_money" => YpayOrder::where('status',1)->whereWeek('create_time')->where('type','wxpay')->sum('truemoney'),//微信本周总金额
            "wechat_today_money" => YpayOrder::where('status',1)->whereDay('create_time')->where('type','wxpay')->sum('truemoney'),//微信今日总金额
            
            "ali_month_money" => YpayOrder::where('status',1)->whereTime('create_time', 'month')->where('type','alipay')->sum('truemoney'),//支付宝本月总金额
            "ali_week_money" => YpayOrder::where('status',1)->whereWeek('create_time')->where('type','alipay')->sum('truemoney'),//支付宝本周总金额
            "ali_today_money" => YpayOrder::where('status',1)->whereDay('create_time')->where('type','alipay')->sum('truemoney'),//支付宝今日总金额
            
            "qq_month_money" => YpayOrder::where('status',1)->whereTime('create_time', 'month')->where('type','qqpay')->sum('truemoney'),//QQ本月总金额
            "qq_week_money" => YpayOrder::where('status',1)->whereWeek('create_time')->where('type','qqpay')->sum('truemoney'),//QQ本周总金额
            "qq_today_money" => YpayOrder::where('status',1)->whereDay('create_time')->where('type','qqpay')->sum('truemoney'),//QQ今日总金额
            
            //统计图 - 总充值
            "wechat_month_recharge" => YpayRecharge::where('status',1)->whereTime('create_time', 'month')->where('type','wxpay')->sum('money'),//微信本月总充值
            "wechat_week_recharge" => YpayRecharge::where('status',1)->whereWeek('create_time')->where('type','wxpay')->sum('money'),//微信本周总充值
            "wechat_today_recharge" => YpayRecharge::where('status',1)->whereDay('create_time')->where('type','wxpay')->sum('money'),//微信今日总充值
            
            "ali_month_recharge" => YpayRecharge::where('status',1)->whereTime('create_time', 'month')->where('type','alipay')->sum('money'),//支付宝本月总充值
            "ali_week_recharge" => YpayRecharge::where('status',1)->whereWeek('create_time')->where('type','alipay')->sum('money'),//支付宝本周总充值
            "ali_today_recharge" => YpayRecharge::where('status',1)->whereDay('create_time')->where('type','alipay')->sum('money'),//支付宝今日总充值
            
            "qq_month_recharge" => YpayRecharge::where('status',1)->whereTime('create_time', 'month')->where('type','qqpay')->sum('money'),//QQ本月总充值
            "qq_week_recharge" => YpayRecharge::where('status',1)->whereWeek('create_time')->where('type','qqpay')->sum('money'),//QQ本周总充值
            "qq_today_recharge" => YpayRecharge::where('status',1)->whereDay('create_time')->where('type','qqpay')->sum('money'),//QQ今日总充值
            
            //在线通道统计
            "total_account" => YpayAccount::where('status',1)->count(),//总在线通道
            "qq_total_account" => YpayAccount::where('status',1)->where('type','qqpay')->count(),//QQ总在线通道
            "wechat_total_account" => YpayAccount::where('status',1)->where('type','wxpay')->count(),//微信总在线通道
            "ali_total_account" => YpayAccount::where('status',1)->where('type','alipay')->count(),//支付宝总在线通道
            
            //订单数据统计
            "today_order" => YpayOrder::where('status',1)->whereDay('create_time')->count(),//今日平台订单
            "today_recharge_order" => YpayRecharge::where('status',1)->whereDay('create_time')->count(),//今日充值订单
            "total_water_order" => $total_water_order,//平台总流水订单
            "total_recharge_order" => $total_recharge_order,//平台总充值订单
        ];
        View::assign('data', $data);
        return $this->fetch();
    }

    // 修改密码
    public function pass(){
        if (Request::isAjax()){
            $this->getJson(S::goPass());
        }
        return $this->fetch();
    }

    // 通用上传
    public function upload(){
        return $this->getJson(Up::putFile(Request::file(),Request::post('path')));
    }

    // 图库选择
    public function optPhoto(){
        if (Request::isAjax()) {
            return $this->getJson(P::getAll());
        }
        return $this->fetch('',P::getPath());
    }
    

}
