<?php
declare (strict_types = 1);

namespace app\common\service;
use think\facade\Session;
use think\facade\Cookie;
use think\facade\Request;
use think\facade\Db;
use app\common\model\YpayUser as M;
use app\common\validate\YpayUser as V;
use app\common\model\YpayVip;
use think\facade\Config;
use app\common\util\Mail;
use app\common\model\AdminFrontLog as Log;

class YpayUser
{
    // 添加
    public static function goAdd($data)
    {
        //验证
        $validate = new V;
        if(!$validate->scene('add')->check($data))
        return ['msg'=>$validate->getError(),'code'=>201];
        $data['password'] = set_password(trim($data['password']));
        
        try {
            M::create($data);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    public static function goUserAdd($data)
    {
        //验证
        $validate = new V;
        if(!$validate->scene('add')->check($data))
        return ['msg'=>$validate->getError(),'code'=>201];
        $data['password'] = set_password(trim($data['password']));
        if(empty($data['vip_time']) || $data['vip_time']=="")
        {
            $data['vip_time'] =null;
        }
        try {
            M::create($data);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    // 编辑
    public static function goUserEdit($data,$id)
    {
        $data['id'] = $id;
        //验证
        $validate = new V;
        if(!$validate->scene('edit')->check($data))
        return ['msg'=>$validate->getError(),'code'=>201];
        if(!empty($data['password']) && $data['password']!="")
        {
            $data['password'] = set_password(trim($data['password']));
        }
        else
        {
            $yuser = M::find($id);
            $data['password'] = $yuser['password'];
        }
        if(empty($data['vip_time']) || $data['vip_time']=="")
        {
            $data['vip_time'] =null;
        }

        try {
             M::update($data);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    // 编辑
    public static function goEdit($data,$id)
    {
        $data['id'] = $id;
        //验证
        $validate = new V;
        if(!$validate->scene('edit')->check($data))
        return ['msg'=>$validate->getError(),'code'=>201];
        if(!empty($data['password']) && $data['password']!="")
        {
            $data['password'] = set_password(trim($data['password']));
        }
        else
        {
            $yuser = M::find($id);
            $data['password'] = $yuser['password'];
        }

        try {
             M::update($data);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    // 冻结/解冻账户
     public static function gofrozenStatus($data,$id)
    {
        //查询是否有此用户
        $model =  M::find($id);
        if ($model->isEmpty())  return ['msg'=>'数据不存在','code'=>201];
        try{
            $model->save([
                'is_frozen' => $data,
            ]);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }

    // 根据ID删除
    public static function goRemove($id)
    {
        $model = M::find($id);
        if ($model->isEmpty()) return ['msg'=>'数据不存在','code'=>201];
        try{
           $model->delete();
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }

    // 批量删除
    public static function goBatchRemove($ids)
    {
        if (!is_array($ids)) return ['msg'=>'数据不存在','code'=>201];
        try{
            M::destroy($ids);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }

    // 获取列表
    public static function goRecycle()
    {
        if (Request::isPost()){
            $ids = Request::param('ids');
            if (!is_array($ids)) return ['msg'=>'参数错误','code'=>'201'];
            try{
                if(Request::param('type')){
                    $data = M::onlyTrashed()->whereIn('id', $ids)->select();
                    foreach($data as $k){
                        $k->restore();
                    }
                }else{
                    M::destroy($ids,true);
                }
            }catch (\Exception $e){
                return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
            }
            return ['msg'=>'操作成功'];
        }
        //按用户名
        $where = [];
        $limit = input('get.limit');
        
               //按会员昵称查找
               if ($nickname = input("nickname")) {
                   $where[] = ["nickname", "like", "%" . $nickname . "%"];
               }
               //按邮箱查找
               if ($email = input("email")) {
                   $where[] = ["email", "like", "%" . $email . "%"];
               }
               //按手机号查找
               if ($mobile = input("mobile")) {
                   $where[] = ["mobile", "like", "%" . $mobile . "%"];
               }
               //按联系QQ查找
               if ($qq = input("qq")) {
                   $where[] = ["qq", "like", "%" . $qq . "%"];
               }
        $list = M::onlyTrashed()->where($where)->paginate($limit);
        return ['code'=>0,'data'=>$list->items(),'extend'=>['count' => $list->total(), 'limit' => $limit]];
    }
    
    // 用户登录
    public static function login(array $data)
    {
        // getConfig()['captcha-type'] 获取验证码类型 Tips: 0:关闭验证码/1:普通验证码/2:腾讯防水墙
        // getConfig()['logincode-type'] 获取登录方式类型 Tips: 0:用户名+密码登录/1:手机号登录/2:邮箱登录
        $captcha_type = getConfig()['captcha-type'];
        $logincode_type = getConfig()['logincode-type'];
        $validate = new V;
        $user = null;
         //调用验证方法数据方法/传入验证码类型和验证码参数
        $ordinary_captcha = empty($data['ordinary_captcha']) ? "":$data['ordinary_captcha'];
        //获取验证验证码信息
        $is_captcha = self::is_captcha($captcha_type,$ordinary_captcha);
        //判断是否有值返回
        if(!empty($is_captcha)){
           return  $is_captcha;
        }
        // 判断登录类型切获取用户数据
        if($logincode_type == 0){
            //验证数据是否填写
            if(!$validate->scene('login')->check($data))return ['msg'=>$validate->getError(),'code'=>201];
            //验证是否存在此用户
            $user = M::where([
                'username' => trim($data['username']),
                'password' => set_password(trim($data['password']))
                ])->find();
        }else if($logincode_type == 1){
                //验证数据是否填写
                if(!$validate->scene('mobile')->check($data))return ['msg'=>$validate->getError(),'code'=>201];
                $code = Session::get('ecode');
                if($data['captcha']==$code)//验证通过
                {
                    $user = M::where([
                    'mobile' => trim($data['mobile'])
                    ])->find();
                }else
                {
                    return ['msg'=>'验证码错误','code'=>201];
                }
        }else{
            //验证数据是否填写
            if(!$validate->scene('email')->check($data))return ['msg'=>$validate->getError(),'code'=>201];
            $code = Session::get('ecode');
            if($data['captcha']==$code)//验证通过
            {
                $user = M::where([
                'email' => trim($data['email'])
                ])->find();
            }
            else
            {
                return ['msg'=>'验证码错误','code'=>201];
            }
        }
 
        if($user['is_frozen']) return ['msg'=>'账号已被冻结,具体原因咨询站长','code'=>201];
        if(!$user){
            
        return ['msg'=>'用户名密码错误','code'=>201];
        } 
        //调用清除缓存方法
        self::clear_captcha_session();
        $user->token = rand_string().$user->id.microtime(true);
        $user->save();
        //是否记住密码
        $time = 3600;
        if (isset($data['remember'])) $time = 30 * 86400;
        //缓存登录信息
        $info = [
            'id' => $user->id,
            'token' => $user->token
        ];
        Session::set('front', $info);
        Cookie::set('front_token',$user->token, $time);
        // 触发登录成功事件
        //event('AdminLog');
        try {
            $info = [
               'uid'       => $user->id,
               'url'      => Request::url(),
               'desc'    => '商户登录成功', 
               'ip'       => Request::ip(),
               'user_agent'=> Request::server('HTTP_USER_AGENT')
            ];
            Log::create($info);
        }catch (\Exception $e){
            
        }
        
        if($user->login_email_tips == 1)//开启了登录提醒
        {
            Mail::go($user->email,'平台登录成功','你好,您的账号ID：'.$user->id.'已登录成功');
        }
        return ['msg'=>'登录成功','code'=>200];
    }
    
    // 用户注册
    public static function register($data)
    {
        return self::reg_or_bind('reg',$data);
     
    }
    
    //快捷登录绑定信息
    public static function bind($data)
    {
         return self::reg_or_bind('bind',$data);

    }
    
    // 根据邮箱找回密码
    public static function golostpwd()
     {
        // getConfig()['captcha-type'] 获取验证码类型 Tips: 0:关闭验证码/1:普通验证码/2:腾讯防水墙
        // getConfig()['regcode-type'] 获取注册方式类型 Tips: 0:用户名+密码+邮箱注册/1:手机号注册/2:邮箱注册
        $captcha_type = getConfig()['captcha-type'];
        $regcode_type = getConfig()['regcode-type'];
        $data = Request::post();
        if(empty($data['emailcode']))
        {
            return ['msg'=>'邮箱验证码不可为空','code'=>201];
        }
         //调用验证方法数据方法/传入验证码类型和验证码参数
        $ordinary_captcha = empty($data['ordinary_captcha']) ? "":$data['ordinary_captcha'];
        //获取验证验证码信息
        $is_captcha = self::is_captcha($captcha_type,$ordinary_captcha);
        //判断是否有值返回
        if(!empty($is_captcha)){
           return  $is_captcha;
        }
        //调用清除缓存方法
        self::clear_captcha_session();
        $code = Session::get('ecode');
        if($data['emailcode']==$code)
        {
            $num = mt_rand(100000,999999);
            M::where('email',$data['email'])->update(['password' => set_password($num)]);
            $res = Mail::go($data['email'],'平台找回密码','你好！，您的新密码为：'.$num.'');
            return ['msg'=>'密码找回成功','code'=>200];
        }else{
            return ['msg'=>'验证码错误!','code'=>201];
        }
        
     }
     
     // 根据手机找回密码
    public static function gomlostpwd()
     {
        // getConfig()['captcha-type'] 获取验证码类型 Tips: 0:关闭验证码/1:普通验证码/2:腾讯防水墙
        // getConfig()['regcode-type'] 获取注册方式类型 Tips: 0:用户名+密码+邮箱注册/1:手机号注册/2:邮箱注册
        $captcha_type = getConfig()['captcha-type'];
        $regcode_type = getConfig()['regcode-type'];
        $data = Request::post();
        if(empty($data['emailcode']))
        {
            return ['msg'=>'手机验证码不可为空','code'=>201];
        }
         //调用验证方法数据方法/传入验证码类型和验证码参数
        $ordinary_captcha = empty($data['ordinary_captcha']) ? "":$data['ordinary_captcha'];
        //获取验证验证码信息
        $is_captcha = self::is_captcha($captcha_type,$ordinary_captcha);
        //判断是否有值返回
        if(!empty($is_captcha)){
           return  $is_captcha;
        }
        //调用清除缓存方法
        self::clear_captcha_session();
        $code = Session::get('mcode');
        if($data['emailcode']==$code)
        {
            $num = mt_rand(100000,999999);
            M::where('mobile',$data['mobile'])->update(['password' => set_password('123456')]);
            return ['msg'=>'密码找回成功','code'=>200];
        }else{
            return ['msg'=>'验证码错误!','code'=>201];
        }
        
     }
    
    // 判断是否登录
    public static function isLogin()
    {
        if(Cookie::has('front_token')){
            $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
            if(!$user) return false;
            Session::set('front',[
                'id' => $user->id,
                'token' => $user->token,
            ]); 
            return true;
        }
        return false;
    }
    
    //验证是否为保护模式
    public static function isAuth()
    {
        if(Session::get('front_auth')) return true;
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        if(empty($user['googlekey']))
        {
            return true;
        }
        return false;
    }
    
    public static function getUserId()
    {
        
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        return $user->id;
    }
    
    // 退出登陆
    public static function logout()
    {
        Session::delete('front_auth');
        Session::delete('front');
        Cookie::delete('front_token');
        Cookie::delete('sign');
        return ['msg'=>'退出成功'];
    }
    
    // 修改密码
     public static function goPass()
     {
        $data = Request::post();
        $validate = new V;
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        M::where('id',$user->id)->update(['password' => set_password(trim($data['newpwd']))]);
        self::logout();
     }

     //获取当前登录的用户信息
     public static function getUser()
     {
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        return $user;
     }
     
     //重置密钥信息
     public static function goUserKey()
     {
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        $data = rand_string();
        M::where('id',$user->id)->update(['user_key' => $data]);
        return $data;
     }
     
    //购买VIP套餐
     public static function govip($data)
    {
        if(empty($data['tcid']))
        {
            return ['msg'=>'请选择套餐','code'=>201];
        }
        $user = M::where(['token'=>Cookie::get('front_token'),'is_frozen'=>0])->find();
        if(!$user) return ['msg'=>'会员不存在','code'=>201];
        $vip = YpayVip::where(['id'=>$data['tcid']])->find();
        if(!$vip) return ['msg'=>'套餐不存在','code'=>201];
        if($user['money']<$vip['money'])
        {
            return ['msg'=>'余额不足请充值','code'=>201];
        }
        try {
            
            M::money("-".$vip['money'],$user->id, '购买套餐扣款');
            //判断是否开启返利功能
            if(getConfig()['is_aff'] && !empty($user['superior_id']) && !empty(getConfig()['aff_percentage']) && getConfig()['aff_type'] == 1){
              $aff_money   = $vip['money']*getConfig()['aff_percentage'];
             M::money("+".$aff_money,$user['superior_id'], '下级购买会员套餐返利');
             M::where('id',$user['superior_id'])->inc('money', $aff_money);
            }
            $viptime = $vip['viptime'];
            if(empty($user['vip_time']))
            {
                M::where('id',$user->id)->update(['vip_time' =>date("Y-m-d H:i:s",strtotime("+ $viptime day")),'feilv'=>$vip['feilv']]);
            }
            else
            {
                if($user['feilv'] == $vip['feilv'] )
                {
                    $sjc = strtotime($user['vip_time']);
                    if($sjc<time())
                    {
                        M::where('id',$user->id)->update(['vip_time' =>date("Y-m-d H:i:s",strtotime("+ $viptime day")),'feilv'=>$vip['feilv']]);
                    }
                    else
                    {
                        $uviptime = $user['vip_time'];
                        M::where('id',$user->id)->update(['vip_time' =>date("Y-m-d H:i:s",strtotime("$uviptime + $viptime day"))]);
                    }
                }
                else
                {
                     M::where('id',$user->id)->update(['vip_time' =>date("Y-m-d H:i:s",strtotime("+ $viptime day")),'feilv'=>$vip['feilv']]);
                }
            }
            return ['msg'=>'操作成功'];
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    //注册/找回公用方法
    public static function reg_or_bind($type,$data){
        // getConfig()['captcha-type'] 获取验证码类型 Tips: 0:关闭验证码/1:普通验证码/2:腾讯防水墙
        // getConfig()['regcode-type'] 获取注册方式类型 Tips: 0:用户名+密码+邮箱注册/1:手机号注册/2:邮箱注册
        $captcha_type = getConfig()['captcha-type'];
        $regcode_type = getConfig()['regcode-type'];
         //验证
        $validate = new V;
        //判断是否是推广链接注册
        if(!empty(session('aff_id'))){
            $data['superior_id'] = session('aff_id');
        }
        //调用验证方法数据方法/传入验证码类型和验证码参数
        $ordinary_captcha = empty($data['ordinary_captcha']) ? "":$data['ordinary_captcha'];
        //获取验证验证码信息
        $is_captcha = self::is_captcha($captcha_type,$ordinary_captcha);
        //判断是否有值返回
        if(!empty($is_captcha)){
           return  $is_captcha;
        }
        //判断验证码是否正确
        if($regcode_type!=0)
        {
            if($regcode_type == 1){
                if(!$validate->scene('mobile')->check($data))return ['msg'=>$validate->getError(),'code'=>201];
            }else{
                if(!$validate->scene('email')->check($data))return ['msg'=>$validate->getError(),'code'=>201];
            }
            $code = Session::get('ecode');
            if($data['captcha']!=$code)
            {
                return ['msg'=>'验证码错误','code'=>201];
            }
        }
        if(!$validate->scene('add')->check($data))
        return ['msg'=>$validate->getError(),'code'=>201];
        //调用清除缓存方法
        self::clear_captcha_session();
        if($type == 'bind'){
            if($data['type'] == 'qq'){
            $data['is_bindqq'] = $data['is_bind'];
            $data['qq_sid'] = $data['open_id'];
            }else{
            $data['is_bindwx'] = $data['is_bind'];
            $data['wx_sid'] = $data['open_id'];
            }
        }
        $data['password'] = set_password(trim($data['password']));
        $data['user_key'] = rand_string();
        $data['username'] = htmlspecialchars($data['username']);
        $data['nickname'] = htmlspecialchars($data['username']);
        $data['feilv'] = "0";
        //检查是否开启赠送余额功能
        $zsoff = getConfig()['is_reg_give_price'];
        if($zsoff==1)
        {
            $data['money'] = getConfig()['reg_give_price'];
        }
        try {
            M::create($data);
        }catch (\Exception $e){
            return ['msg'=>'操作失败'.$e->getMessage(),'code'=>201];
        }
    }
    
    //清除第三方验证码缓存记录[极验/腾讯云防水墙]
    public static function clear_captcha_session(){
        //判断是否存在验证的Session并清除
        if(session('tencentCaptcha') || session('geetestCaptcha')){
            //清除关于腾讯防水墙的Session
            session('tencentCaptcha', null);
            //清除关于极验的Session
            session('geetestCaptcha', null);
        }
    }
    
    //判断验证码是否为空和验证
    public static function is_captcha($captcha_type,$ordinary_captcha=""){
        // 判断普通验证码是否为空
        if($captcha_type==1 &&  empty($ordinary_captcha) )
        {
            return ['msg'=>'请输入验证码','code'=>201];
        }
        // 判断腾讯防水墙是否验证
        if($captcha_type==2 && session('tencentCaptcha') !=1)
        {
            return ['msg'=>'请先完成验证码验证','code'=>201];
        }
        //判断极验是否验证
        if($captcha_type==3 && session('geetestCaptcha') !=1)
        {
            return ['msg'=>'请先完成验证码验证','code'=>201];
        }
        //判断验证码是否正确
        if($captcha_type==1 && !captcha_check($ordinary_captcha))
        {
              return ['msg'=>'验证码错误','code'=>201];
        }
    }
    
    public static function thirdlogin($user)
    {
        $user['token'] = rand_string().$user['id'].microtime(true);
        M::where('id',$user['id'])->update(['token' =>$user['token']]);
        //是否记住密码
        $time = 3600;
        if (isset($data['remember'])) $time = 30 * 86400;
        //缓存登录信息
        $info = [
            'id' => $user['id'],
            'token' => $user['token']
        ];
        Session::set('front', $info);
        Cookie::set('front_token',$user['token'], $time);
        try {
            $info = [
               'uid'       => $user['id'],
               'url'      => Request::url(),
               'desc'    => '商户快捷登录成功', 
               'ip'       => Request::ip(),
               'user_agent'=> Request::server('HTTP_USER_AGENT')
            ];
            Log::create($info);
        }catch (\Exception $e){
            
        }
        return ['msg'=>'登录成功'];
    }
}
