<?php
declare (strict_types = 1);

namespace app\index\controller;
use think\facade\Request;
use think\captcha\facade\Captcha;
use app\common\service\YpayUser as S;
use app\common\model\YpayUser as M;
use app\common\util\TenCloudSms;
use app\common\util\AliSms;
use app\common\util\SmsBao;
use app\common\util\Mail;
use think\facade\Session;
use think\facade\Cookie;
use think\facade\Config;
use think\facade\Db;
use think\facade\View;
use app\common\service\Third;

class User extends \app\BaseController
{
    /**
     * 首页
     */
    public function index()
    {
        if (!S::isLogin()){
            return redirect(Request::root().'/User/Login');
        }
        $user = M::where(['id'=>S::getUserId(),'is_frozen'=>0])->find();
        if(!$user){
            S::logout();
           return redirect(Request::root().'/User/Login'); 
        }
        return $this->fetch('',$this->getSystem());
    }
     
    //登录
    public function login()
    {
        if (Request::isAjax()){
            if (S::isLogin())
            {
                $this->getJson(['msg'=>'重复登录,跳转中']);
            }
            $this->getJson(S::login(Request::param('','','strip_tags')));
        }
        if (S::isLogin()){
            return redirect(Request::root().'/User/Index');
        }
        //调用清除缓存方法
        S::clear_captcha_session();
        
        return $this->fetch();
    }
    
    
    //获取短信验证码emaillogin
    public function getlogincode($mobile='',$email='')
    {
        $num = mt_rand(100000,999999);
        Session::set('ecode', $num);
        if(getConfig()['logincode-type']==1)
        {
            $model =  M::where('mobile',$mobile)->find();
            if(empty($model))
            {
                return json(['code'=>201,'msg'=>'该手机号不存在!']);
            }
            if(getConfig()['smstype']==1)
            {
                $res = AliSms::send($mobile,$num);
            }
            else if(getConfig()['smstype']==2)
            {
                $res = TenCloudSms::goLogin($mobile,$num);
            }
            else
            {
                $res = SmsBao::go($num,$mobile);
            }
        }
        else
        {
            $model =  M::where('email',$email)->find();
            if(empty($model))
            {
                return json(['code'=>201,'msg'=>'该邮箱不存在!']);
            }
            $res = Mail::go($email,'平台登录验证码','你好！，验证码为：'.$num.'，5分钟内有效');
        }
        if(!$res)
        {
            return json(['code'=>201,'msg'=>'发送失败!']);
        }
        return json(['code'=>200,'msg'=>'发送成功!']);
    }
    
    
    public function getregcode($mobile='',$email='')
    {
        $num = mt_rand(100000,999999);
        Session::set('ecode', $num);
        if(getConfig()['regcode-type']==1)
        {
            $model =  M::where('mobile',$mobile)->find();
            if(!empty($model))
            {
                return json(['code'=>201,'msg'=>'该手机号已存在!']);
            }
            if(getConfig()['smstype']==1)
            {
                //生成随机六位数，不足六位两边补零
                $res = AliSms::send($mobile,$num);
            }
            else if(getConfig()['smstype']==2)
            {
                $res = TenCloudSms::goReg($mobile,$num);
            }
            else
            {
                $res = SmsBao::go($num,$mobile);
            }
        }
        else
        {
            $model =  M::where('email',$email)->find();
            if(!empty($model))
            {
                return json(['code'=>201,'msg'=>'该邮箱已存在!']);
            }
            $res = Mail::go($email,'平台注册验证码','你好！，验证码为：'.$num.'，5分钟内有效');
        }
        if(!$res)
        {
            return json(['code'=>201,'msg'=>'发送失败!']);
        }
        return json(['code'=>200,'msg'=>'发送成功!']);
    }
    
    
    public function getlostcode($email='')
    {
        $num = mt_rand(100000,999999);
        Session::set('ecode', $num);
        $model =  M::where('email',$email)->find();
        if(empty($model))
        {
            return json(['code'=>201,'msg'=>'该邮箱不存在!']);
        }
        $res = Mail::go($email,'平台找回密码验证码','你好！，验证码为：'.$num.'，5分钟内有效');
        if(!$res)
        {
            return json(['code'=>201,'msg'=>'发送失败!']);
        }
        return json(['code'=>200,'msg'=>'发送成功!']);
    }
    
    public function getmlostcode($mobile='')
    {
        $num = mt_rand(100000,999999);
        Session::set('mcode', $num);
        $model =  M::where('mobile',$mobile)->find();
        if(empty($model))
        {
            return json(['code'=>201,'msg'=>'该手机号不存在!']);
        }
        if(getConfig()['smstype']==1)
        {
            //生成随机六位数，不足六位两边补零
            $res = AliSms::send($mobile,$num);
        }
        else if(getConfig()['smstype']==2)
        {
            $res = TenCloudSms::goReg($mobile,$num);
        }
        else
        {
            $res = SmsBao::go($num,$mobile);
        }
        if(!$res)
        {
            return json(['code'=>201,'msg'=>'发送失败!']);
        }
        return json(['code'=>200,'msg'=>'发送成功!']);
    }
    
    
    //注册
    public function reg()
    {
        if (S::isLogin())
        {
            return redirect(Request::root().'/User/Index');
        }
        if (Request::isAjax()){
            
            if(getConfig()['is_reg']!=1)
            {
                return json(['code'=>201,'msg'=>'注册功能已关闭!']);
            }
            
            $this->getJson(S::register(Request::param('','','strip_tags')));
        }
        //调用清除缓存方法
        S::clear_captcha_session();
        return $this->fetch();
    }
    
    //绑定快捷登录
    public function bind()
    {
        if (S::isLogin())
        {
            return redirect(Request::root().'/User/Index');
        }
        if (Request::isAjax()){
            $this->getJson(S::bind(Request::param('','','strip_tags')));
        }
        $data = array(
            'type' => session('type'),
            'username' => session('username'),
            'sid'   => session(session('type').'_sid'),
            'is_bind'=> session('is_bind'.session('type'))
            ); 
        if(empty($data['type']) || empty($data['username']) || empty($data['sid']) || empty($data['is_bind'])){
            exit('对应参数为空,请重新使用快捷登录');
        }
        //调用清除缓存方法
        S::clear_captcha_session();
        View::assign('data', $data);
        return $this->fetch();
    }
    
    //找回密码
    public function lostpwd()
    {
        if (Request::isAjax()){
            $this->getJson(S::golostpwd(Request::param('','','strip_tags')));
        }
        
        //调用清除缓存方法
        S::clear_captcha_session();
        return $this->fetch();
    }
    
    public function mlostpwd()
    {
        if (Request::isAjax()){
            $this->getJson(S::gomlostpwd(Request::param('','','strip_tags')));
        }
        
        //调用清除缓存方法
        S::clear_captcha_session();
        return $this->fetch();
    }
    
    //验证码
    public function verify(){
        ob_clean(); 
        return Captcha::create();
    }
    
    //退出登录
    public function logout(){
        S::logout();
        return redirect(Request::root().'/User/Login');
    }
    
    public function userann()
    {
        return $this->fetch();
    }
    
    //发起聚合登录
    public function OAuthAccountLogin($type)
    {
        $loginurl = Third::OAuthAccountLogin($type);
        if($loginurl['code']!=0)
        {
            exit($loginurl['msg']);
        }
        View::assign('url', $loginurl['url']);
        return $this->fetch();
    }
    
    //发起QQ互联登录
    public function qqlogin()
    {
        $http_type = ((isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') || (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')) ? 'https://' : 'http://';
        $qqOAuth = new \Yurun\OAuthLogin\QQ\OAuth2(getConfig()['qq_appid'], getConfig()['qq_appkey'],$http_type.$_SERVER['HTTP_HOST'].'/Notify/qqcallback');
        $url = $qqOAuth->getAuthUrl();
        Session::set('YURUN_QQ_STATE', $qqOAuth->state);
        header('location:' . $url);
        die;
    }
    
    //二次验证验证码
    public function Captcha()
    {   
        //获取提交数据
        $data = Request::param('','','strip_tags');
        //获取数据库配置信息
        $config = getConfig();
        if($config['captcha-type'] == 2){
            header('Content-type:application/json; Charset=utf-8');
            $url = 'https://ssl.captcha.qq.com/ticket/verify';
            $appid = $config['tencent_CaptchaAppId'];
            $AppSecretKey = $config['tencent_CaptchaKey'];
            $Ticket = isset($data['ticket']) ? $data['ticket'] : '';
            $Randstr = isset($data['randstr']) ? $data['randstr'] : '';
            $UserIP = request()->ip();
            $params = array(
                "aid" => $appid,
                "AppSecretKey" => $AppSecretKey,
                "Ticket" => $Ticket,
                "Randstr" => $Randstr,
                "UserIP" => $UserIP
            );
            $data = http_build_query($params);
            $result = get_curl($url,$data);
            $res = json_decode($result, true);
            if (isset($res) && $res['response']==1) {
                Session::set('tencentCaptcha', 1);
                return json(['code'=>200,'msg'=>session('tencentCaptcha')]);
            }else{
                Session::set('tencentCaptcha', 0);
                return json(['code'=>201,'msg'=>session('tencentCaptcha')]);
            }
        }else{
            header('Content-type:application/x-www-form-urlencoded');
            $url = 'http://gcaptcha4.geetest.com/validate';
            $appid = $config['geetest_CaptchaAppId'];
            $AppSecretKey = $config['geetest_CaptchaKey'];
            $lot_number = $data['lot_number'];
            $captcha_output = $data['captcha_output'];
            $pass_token = $data['pass_token'];
            $gen_time = $data['gen_time'];
            // 生成签名
            $sign_token = hash_hmac('sha256', $lot_number, $AppSecretKey);
            // 4.上传校验参数到极验二次验证接口, 校验用户验证状态
            $query = array(
                'captcha_id' =>$appid,
                "lot_number" => $lot_number,
                "captcha_output" => $captcha_output,
                "pass_token" => $pass_token,
                "gen_time" => $gen_time,
                "sign_token" => $sign_token
            );
            $data = http_build_query($query);
            $result = get_curl($url,$data);
            $res = json_decode($result, true);
            if($res['result'] == 'success'){
                Session::set('geetestCaptcha', 1);
                return json($res);
            }else{
                Session::set('geetestCaptcha', 0);
                return json($res);
            }
            
        }
        
    }
    
    
    
    
    
    
}
